#!/usr/bin/perl

#===============================================================================
#     REVISION:  $Id: test5-1.pl 2 2010-06-04 13:42:47Z xdr.box $
#  DESCRIPTION:  no violations
#===============================================================================

use strict;
use warnings;

our $VERSION = '1.0';

sub main {
    return;
}

main();

